.. _greffe:

.. raw:: html

    <br>
    <center>

greffe
======

.. raw:: html

    </center>
    <br>

.. image:: ../jpg/nederland2.jpg
    :width: 100%
    :height: 4cm


| 2012/11/8 Bart Thate <bthate@gmail.com<mailto:bthate@gmail.com>>

|                            Le Greffe
|                            Cour Europeenne des Droits de l'Homme
|                            Conseil de l'Europe
|                            F-67075 STRASBOURG CEDEX.


|                                                   8 november 2012


| uw kenmerk: 69389/12
| mijn kenmerk: 20121108-1


In and about the year 2000, the government of the Netherlands, through the 
industry of the GGZ, the mental healthcare business, introduced an adapted 
method of treating people with a serious mental illness, that would be chea
per than the version it was derived from.

The original treatement recognized that for people with such a sickness the
re is a prerequirement for healing that is called the continuity of care. P
eople who have to deal with "things that are not there", can get it so diff
icult dealing with that, that they need to have access to someone who can h
elp them with those situations 24 hours a day. This is a necessity. Without
this garantuee there is no chance of  recovery from the illness for the pa
tient. Because without this support the situation can get unbearble and peo
ple deprive themselves from their lives to escape the hell they are living 
in.

When schizophrenic people hallucinate they are actually dreaming when being
conscious (awake, there in reality) as well. Because one is awake and drea
ming at the same time, for us, what we dream is real.

By introduction of the new system in the Netherlands, this 24/7 support is 
taken away from the patient and replace by a front-end back-end system, whe
re the front-end decides whether the situation of the patient is severe eno
ugh to take action. A diagnose of this front-end that further help is not -
immediately - necessary, is a death cause for patients with serious mental
illnesses. The refusal to even acknowledge that the patient is in dire nee
d, to tell him to wait until monday to get some real help, put this patient
in a situation where he has to deal with himself not wanting to be here an
y more for more than 45 hours.

The terror, horror, fear, panic, dispair of people that can no longer hold 
it in this life during this period is enormous. Not only because of the  si
ckness, but mostely due to the knowledge that there will be no help.

It is left alone, we don't care if you die, have a nice weekend !!

This new method (FACT - Functional Assertive Community Treatement) is never
tested. The effects of the new elements that were introduced with this met
hod of treatement, were never tested. People in the psychiatric field knew 
this, the directive for the treatement of schizophrenic people here in the 
Netherlands says that this treatement should be tested before deployment of
it on  a wider scale can happen.

The industry has not listened to this advice. Right now there are 150 teams
in the Netherlands that are taking away support for sick people in the wee
kend. Plans are to grown this number to 500 in the coming years.

This treatement is sold to the government on the promise to reduce the need
for hospitalisation of patients here in the Netherlands. After 10 years of
using this treatement with out any testing, the first research shows that 
the treatement does NOT lead to less need for hospitalisation. What is to b
e expected when the patient is without help the whole weekend. Most suicide
s happen in the weekend.

The method where it is based on (ACT) is preventive for further hospitalisa
tion and can indeed allow patients like me and some other 250 thousand pati
ents here in the Netherlands learn how to deal with this "dreaming on the d
ay", dealing with hallucinations and who can, with the right support and ba
ckup for difficult situations in life, regain a part of their original stre
ngth back. I was when I came in this program at 50% of my original skill se
t. Able to talk, communicate, have connections in this world.
The workings of this method is proven by science, numerous tests have been 
done that show the effectiveness on it. Because the people who developed it
truly looked at what the patients needs. And then try to provide those bas
ic requirements for life.

This proven, working method of treatement is withheld from me and my people
.
Right now I am truly alone, none left to help me any more. People always wi
sh me good luck with the struggle I am having to get attention to this prob
lem. In the hell we are living in there is only bad luck. This sickness is 
like being mentally in a wheelchair, not able to move for ourselves. We are
socially handicapped. Nobody wants us, nobody needs us, nobody gives a shi
t whether we are in this world or not.

I can understand some of this. This hallucination things scares people. It 
scares me as well !! I don't blame normal people for not knowing how to dea
l with people like me. It is just too difficult for them to understand, and
what one does not understand scares.

But the people who get paid to help me to have - some - of a life, they are
just not there when I need them.

The GGZ industry made the cost for this treatement lower from 10 thousand e
uro a year to 7 thousand. Cheaper for the country and the patient will be s
ocially integrated with it as well !! The magic "we do more with less" thin
king.

They withhold me from the proper care I need. My social wheelchair with whi
ch I can socially participate instead alone here at home.  Being alone is n
ever good for anybody. Being alone with your - real - imagination is deadly
for those who can not hold longer. Being without any living connection in 
this earth is ...

I want to bring this matter to the European Court for the Human Rights. I w
ant my government to ackowledge the thing i am speaking of here. I also wan
t my country to take - proper - measures to give my people (and me) the car
e that is needed to take part in life as any other of you do. Especially in
the weekend.

We can live, we can have a place in society. But we can only do that if the
people that need to help us are there when they are needed.
*Right to live* -  My country withholds me from the care I need to live.

*Torture* - My country lets people with a killer in their head, deal with t
hat, alone at home, for more than 40 hours, before they can get somebody to
listen to their problems.

*Denial of proper court of law* - My country has prevented me from bringing
this to the Judge.

*Unforgivable* -  My country does not want to learn from things that go wor
ng. They prefer to ignore them.



|                            Le Greffe
|                            Cour Europeenne des Droits de l'Homme
|                            Conseil de l'Europe
|                            F-67075 STRASBOURG CEDEX.


|                                                  19 december 2012


| uw kenmerk: 69389/12
| mijn kenerk: 20121219-1


Dear Court,

I add 1 fact to the facts mentioned in 20121209-1 and that is the fact that
social pain (exclusion pain) is registered by the same brain area that reg
isters physical. For the human experiencing social exclusion that results i
n real pain that is felt.

See http://www.apa.org/monitor/2012/04/rejection.aspx for an explanation of
this fact.

Psychological Bulletin
2005, Vol. 131, No. 2, 202-223
Copyright 2005 by the American Psychological Association
0033-2909/05/$12.00 DOI: 10.1037/0033-2909.131.2.202

found at http://www.sozialpsychologie.uni-frankfurt.de/wp-content/uploads/2
010/09/MacDonald-Leary-20051.pdf

The following url gives the actual proof with brain scans.

http://www.nature.com/nrn/journal/v13/n6/box/nrn3231_BX4.html


The pain of social disconnection: examining the shared neural underpinnings
of physical and social pain
Naomi I. Eisenberger
Nature Reviews Neuroscience 13, 421-434 (June 2012)
:10.1038/nrn3231


I ask the court for immediate action on my case, as my situation is dire. I
not only have to undergo the pain described above, every day, for many day
s on end now, i also have to fear for my life, every day, as no help is ava
ilable to relieve me of this pain.

A refusal of request for care is for a patient the most extreme case of rej
ection pain.


Bart Thate

